@@ -8,7 +8,7 @@ from typeguard import typechecked
 
 __all__ = ["TicToc"]
 __author__ = "Chris Mahoney"
-__version__ = "1.1.1"
+__version__ = "1.1.2"
 
 
 class TicToc:
@@ -228,6 +228,11 @@ class TicToc:
         """
         self.toc(restart=restart, print_time=False)
         return self.elapsed
+    
+    @typechecked
+    def toc_string(self, restart: bool = False) -> str:
+        self.toc(restart=restart, print_time=False)
+        return self._format_duration(self.elapsed)
 
     def __enter__(self) -> None:
         """
